==> jc-1.4.0.tar.gz: polyglot/util/NestedMap__242.h <==
// class polyglot.util.NestedMap$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1fbd37688178fd7d polyglot_util_NestedMap__242

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_NestedMap__242_H_
#define _JC_polyglot_util_NestedMap__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_util_NestedMap$object;

// Typedefs
typedef struct _jc_polyglot_util_NestedMap__242$sub_refs	_jc_polyglot_util_NestedMap__242$sub_refs;
typedef struct _jc_polyglot_util_NestedMap__242$sub_nonrefs	_jc_polyglot_util_NestedMap__242$sub_nonrefs;
typedef struct _jc_polyglot_util_NestedMap__242$refs	_jc_polyglot_util_NestedMap__242$refs;
typedef struct _jc_polyglot_util_NestedMap__242$nonrefs	_jc_polyglot_util_NestedMap__242$nonrefs;
typedef struct _jc_polyglot_util_NestedMap__242$object	_jc_polyglot_util_NestedMap__242$object;

typedef const struct _jc_polyglot_util_NestedMap__242$vmethods	_jc_polyglot_util_NestedMap__242$vmethods;
typedef const struct _jc_polyglot_util_NestedMap__242$vtable	_jc_polyglot_util_NestedMap__242$vtable;
typedef const struct _jc_polyglot_util_NestedMap__242$vtype	_jc_polyglot_util_NestedMap__242$vtype;

// Constructors
extern void _jc_polyglot_util_NestedMap__242$method$_init$e86507e3abc60b21(_jc_env *, struct _jc_polyglot_util_NestedMap__242$object *, struct _jc_polyglot_util_NestedMap$object *);

// Virtual methods
extern jboolean _jc_polyglot_util_NestedMap__242$method$isTrue$91ea4ebb04f439fb(_jc_env *, struct _jc_polyglot_util_NestedMap__242$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_NestedMap__242$method_info$isTrue$91ea4ebb04f439fb;

// Virtual methods structure
struct _jc_polyglot_util_NestedMap__242$vmethods {
	jboolean	(*isTrue$91ea4ebb04f439fb)(_jc_env *, struct _jc_polyglot_util_NestedMap__242$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_polyglot_util_NestedMap__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_NestedMap__242$vmethods	polyglot_util_NestedMap__242;
};

// Vtype
struct _jc_polyglot_util_NestedMap__242$vtype {
	_jc_type			type;
	_jc_polyglot_util_NestedMap__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__242$sub_refs {
	struct _jc_polyglot_util_NestedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_util_NestedMap__242$refs {
    _jc_polyglot_util_NestedMap__242$sub_refs	polyglot_util_NestedMap__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_NestedMap__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_NestedMap__242$sub_nonrefs	polyglot_util_NestedMap__242;
};

// Object instance structure
struct _jc_polyglot_util_NestedMap__242$object {
	_jc_polyglot_util_NestedMap__242$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_NestedMap__242$vtype	*vtype;
	_jc_polyglot_util_NestedMap__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_NestedMap__242$vtype _jc_polyglot_util_NestedMap__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_NestedMap__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_NestedMap__242$class_object;

#endif	/* _JC_polyglot_util_NestedMap__242_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/NestedMap__242.h <==
// class polyglot.util.NestedMap$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1fbd37688178fd7d polyglot_util_NestedMap__242

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_NestedMap__242_H_
#define _JC_polyglot_util_NestedMap__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_util_NestedMap$object;

// Typedefs
typedef struct _jc_polyglot_util_NestedMap__242$sub_refs	_jc_polyglot_util_NestedMap__242$sub_refs;
typedef struct _jc_polyglot_util_NestedMap__242$sub_nonrefs	_jc_polyglot_util_NestedMap__242$sub_nonrefs;
typedef struct _jc_polyglot_util_NestedMap__242$refs	_jc_polyglot_util_NestedMap__242$refs;
typedef struct _jc_polyglot_util_NestedMap__242$nonrefs	_jc_polyglot_util_NestedMap__242$nonrefs;
typedef struct _jc_polyglot_util_NestedMap__242$object	_jc_polyglot_util_NestedMap__242$object;

typedef const struct _jc_polyglot_util_NestedMap__242$vmethods	_jc_polyglot_util_NestedMap__242$vmethods;
typedef const struct _jc_polyglot_util_NestedMap__242$vtable	_jc_polyglot_util_NestedMap__242$vtable;
typedef const struct _jc_polyglot_util_NestedMap__242$vtype	_jc_polyglot_util_NestedMap__242$vtype;

// Constructors
extern void _jc_polyglot_util_NestedMap__242$method$_init$e86507e3abc60b21(_jc_env *, struct _jc_polyglot_util_NestedMap__242$object *, struct _jc_polyglot_util_NestedMap$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_util_NestedMap__242$method$isTrue$91ea4ebb04f439fb(_jc_env *, struct _jc_polyglot_util_NestedMap__242$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_NestedMap__242$method_info$isTrue$91ea4ebb04f439fb;

// Virtual methods structure
struct _jc_polyglot_util_NestedMap__242$vmethods {
	jboolean	(*isTrue$91ea4ebb04f439fb)(_jc_env *, struct _jc_polyglot_util_NestedMap__242$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_NestedMap__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_NestedMap__242$vmethods	polyglot_util_NestedMap__242;
};

// Vtype
struct _jc_polyglot_util_NestedMap__242$vtype {
	_jc_type			type;
	_jc_polyglot_util_NestedMap__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__242$sub_refs {
	struct _jc_polyglot_util_NestedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_util_NestedMap__242$refs {
    _jc_polyglot_util_NestedMap__242$sub_refs	polyglot_util_NestedMap__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_NestedMap__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_NestedMap__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_NestedMap__242$sub_nonrefs	polyglot_util_NestedMap__242;
};

// Object instance structure
struct _jc_polyglot_util_NestedMap__242$object {
	_jc_polyglot_util_NestedMap__242$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_NestedMap__242$vtype	*vtype;
	_jc_polyglot_util_NestedMap__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_NestedMap__242$vtype _jc_polyglot_util_NestedMap__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_NestedMap__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_NestedMap__242$class_object;

#endif	/* _JC_polyglot_util_NestedMap__242_H_ */
